==> GenomeARTIST_v1.17b_src.zip: src/exenne/components/coloredtable/JColoredTable.java <==
/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package exenne.components.coloredtable;

import exenne.components.coloredtable.cellrenderers.AbstractColoredCellRenderer;
import exenne.components.coloredtable.cellrenderers.DefaultColoredCellRenderer;
import exenne.components.jtable.configuredtable.JExenneAbstractTable;
import java.awt.Rectangle;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.math.BigDecimal;
import javax.swing.table.TableCellRenderer;
import javax.swing.table.TableModel;

/**
 *
 * @author iulian
 */
public class JColoredTable extends JExenneAbstractTable {

    /**~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
     *     Constructori
     *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/
    
    /**
     * Construiesc un tabel care rendeaza randurile prietenos
     * @param dm 
     */
    public JColoredTable(AbstractColoredTableModel dm) {
        super(dm);
        AbstractColoredCellRenderer renderer = new DefaultColoredCellRenderer();
        setDefaultCellRenderer(renderer);
        
        //Inregistrez ascultator de mouse
        this.addMouseListener(mouseListener);
    }

    /**~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
     *     Getteri publici
     *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/
    
    /**
     * Obtine modelul din spate
     * @return
     */
    @Override
    public AbstractColoredTableModel getModel() {
        return (AbstractColoredTableModel) super.getModel();
    }
    
    /**~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
     *     Setteri publici
     *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/
    
    /**
     * Seteaza un cellrenderer default
     */
    public void setDefaultCellRenderer(AbstractColoredCellRenderer renderer) {
        setDefaultRenderer(Object.class,
                renderer);
        setDefaultRenderer(BigDecimal.class,
                renderer);
        setDefaultRenderer(Integer.class,
                renderer);
        setDefaultRenderer(String.class,
                renderer);
    }

    /**
     * Seteaza un cellrenderer default
     * @param columnClass
     * @param renderer
     */
    @Override
    public void setDefaultRenderer(Class<?> columnClass, TableCellRenderer renderer) {
        if (renderer instanceof AbstractColoredCellRenderer)
            super.setDefaultRenderer(columnClass, renderer);
        else return;
    }

    /**
     * Seteaza modelul din spate
     * @param dataModel
     */
    @Override
    public void setModel(TableModel dataModel) {
        if (dataModel instanceof AbstractColoredTableModel)
            super.setModel(dataModel);
        else return;
    }

    /**
     * Seteaza modelul din spate
     * @param dataModel
     */
    public void setModel(AbstractColoredTableModel dataModel) {
        super.setModel(dataModel);
    }

    /**~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
     *     Actiuni publice
     *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/

    /**
     * Selecteaza un rand
     */
    public void selectRow(int row) {
        //Select the row
        int numberOfRows = this.getRowCount();
        if (row >= 0 && row < numberOfRows) {
            this.addRowSelectionInterval(row, row);
        }
        if (row >= 0 && row < numberOfRows) {
            this.addRowSelectionInterval(row, row);
        }
    }

    /**
     * Selecteaza si fa scroll la randul selectat
     * @param row
     */
    public void selectAndScrollToRow(int row) {
        int numberOfRows = this.getRowCount();
        if (row >= 0 && row < numberOfRows) {
            this.addRowSelectionInterval(row, row);
            Rectangle rectangle = this.getCellRect(row, 0, true);
            this.scrollRectToVisible(rectangle);
        }
    }

    /**~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
     *     Clase interne
     *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/
    
    /**
     * Ascultator pentru extindere la click mijloc
     */
    private MouseListener mouseListener = new MouseAdapter() {
        
        /**
         * Metoda apelata la clickul de mouse
         */
        @Override
        public void mousePressed(MouseEvent e) {
            maybeDisableSelection(e);
        }

        /**
         * Daca nu e selectat nimic deselectez elementele selectate
         */
        private void maybeDisableSelection(MouseEvent e) {
            //Identifica randul
            int row = JColoredTable.this.rowAtPoint(e.getPoint());
            if(row == -1)
                JColoredTable.this.clearSelection();
        }
    };
    
}

==> GenomeARTIST_v1.19_src.zip: src/exenne/components/coloredtable/JColoredTable.java <==
/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package exenne.components.coloredtable;

import exenne.components.coloredtable.cellrenderers.AbstractColoredCellRenderer;
import exenne.components.coloredtable.cellrenderers.DefaultColoredCellRenderer;
import java.awt.Rectangle;
import java.math.BigDecimal;
import javax.swing.JTable;
import javax.swing.table.TableCellRenderer;
import javax.swing.table.TableModel;

/**
 *
 * @author iulian
 */
public class JColoredTable extends JTable {
    public JColoredTable(AbstractColoredTableModel dm) {
        super(dm);
        AbstractColoredCellRenderer renderer = new DefaultColoredCellRenderer();
        setDefaultCellRenderer(renderer);
    }

    /**
     * Seteaza un cellrenderer default
     */
    public void setDefaultCellRenderer(AbstractColoredCellRenderer renderer) {
        setDefaultRenderer(Object.class,
                renderer);
        setDefaultRenderer(BigDecimal.class,
                renderer);
        setDefaultRenderer(Integer.class,
                renderer);
        setDefaultRenderer(String.class,
                renderer);
    }

    /**
     * Seteaza un cellrenderer default
     * @param columnClass
     * @param renderer
     */
    @Override
    public void setDefaultRenderer(Class<?> columnClass, TableCellRenderer renderer) {
        if (renderer instanceof AbstractColoredCellRenderer)
            super.setDefaultRenderer(columnClass, renderer);
        else return;
    }


    /**
     * Seteaza modelul din spate
     * @param dataModel
     */
    @Override
    public void setModel(TableModel dataModel) {
        if (dataModel instanceof AbstractColoredTableModel)
            super.setModel(dataModel);
        else return;
    }


    /**
     * Seteaza modelul din spate
     * @param dataModel
     */
    public void setModel(AbstractColoredTableModel dataModel) {
        super.setModel(dataModel);
    }

    /**
     * Obtine modelul din spate
     * @return
     */
    @Override
    public AbstractColoredTableModel getModel() {
        return (AbstractColoredTableModel) super.getModel();
    }

    /**
     * Selecteaza un rand
     */
    public void selectRow(int row) {
        int numberOfRows = this.getRowSorter().getViewRowCount();
        if (row >= 0 && row < numberOfRows) {
            this.addRowSelectionInterval(row, row);
        }
    }

    /**
     * Selecteaza si fa scroll la randul selectat
     * @param row
     */
    public void selectAndScrollToRow(int row) {
        int numberOfRows = this.getRowSorter().getViewRowCount();
        if (row >= 0 && row < numberOfRows) {
            this.addRowSelectionInterval(row, row);
            Rectangle rectangle = this.getCellRect(row, 0, true);
            this.scrollRectToVisible(rectangle);
        }
    }

}
